==> dapware-commons-1.0.2-sources.jar: com/digiwin/dap/middleware/commons/crypto/DigestUtils.java <==
package com.digiwin.dap.middleware.commons.crypto;

import cn.hutool.crypto.digest.DigestUtil;
import com.auth0.jwt.JWT;
import com.auth0.jwt.algorithms.Algorithm;
import com.digiwin.dap.middleware.commons.core.codec.Base64;
import com.digiwin.dap.middleware.commons.crypto.constant.KeyConstant;
import com.digiwin.dap.middleware.commons.util.StrUtils;

/**
 * 摘要算法工具类
 *
 * @author fobgochod
 * @since 1.0.0
 */
public class DigestUtils {

    /**
     * 计算sha256摘要值
     *
     * @param data 被摘要数据
     * @return SHA-256摘要
     */
    public static String sha256(String data) {
        return sha256(data, 2);
    }

    /**
     * 计算sha256摘要值
     *
     * @param data  被摘要数据
     * @param count 摘要计算次数
     * @return SHA-256摘要
     */
    public static String sha256(String data, int count) {
        byte[] digest = StrUtils.bytes(data);
        for (int i = 0; i < count; i++) {
            digest = DigestUtil.sha256(digest);
        }
        return Base64.encode(digest);
    }

    /**
     * 计算32位MD5摘要值，并转为16进制字符串
     *
     * @param data 被摘要数据
     * @return md5摘要
     */
    public static String md5Hex(String data) {
        return DigestUtil.md5Hex(StrUtils.bytes(data));
    }

    /**
     * 根据应用id去创建token信息
     * 保证每一区的token一致
     *
     * @param sysId 应用ID
     * @return appToken
     * @since 1.0.2
     */
    public static String getAppToken(String sysId) {
        try {
            Algorithm algorithm = Algorithm.HMAC256(KeyConstant.OTHER);
            return JWT.create()
                    .withClaim("id", sysId)
                    .withClaim("sid", 0L)
                    .sign(algorithm);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }
}

==> dapware-commons-1.0.4-sources.jar: com/digiwin/dap/middleware/commons/crypto/DigestUtils.java <==
package com.digiwin.dap.middleware.commons.crypto;

import cn.hutool.crypto.digest.DigestAlgorithm;
import cn.hutool.crypto.digest.DigestUtil;
import com.auth0.jwt.JWT;
import com.auth0.jwt.algorithms.Algorithm;
import com.digiwin.dap.middleware.commons.core.codec.Base64;
import com.digiwin.dap.middleware.commons.crypto.constant.KeyConstant;
import com.digiwin.dap.middleware.commons.util.StrUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.security.MessageDigest;

/**
 * 摘要算法工具类
 *
 * @author fobgochod
 * @since 1.0.0
 */
public class DigestUtils {

    private static final Logger logger = LoggerFactory.getLogger(DigestUtils.class);

    /**
     * 计算sha256摘要值
     *
     * @param data 被摘要数据
     * @return SHA-256摘要
     */
    public static String sha256(String data) {
        return sha256(data, 2);
    }

    /**
     * 计算sha256摘要值
     *
     * @param data  被摘要数据
     * @param count 摘要计算次数
     * @return SHA-256摘要
     */
    public static String sha256(String data, int count) {
        byte[] digest = StrUtils.bytes(data);
        for (int i = 0; i < count; i++) {
            digest = DigestUtil.sha256(digest);
        }
        return Base64.encode(digest);
    }

    /**
     * 计算32位MD5摘要值，并转为16进制字符串
     *
     * @param data 被摘要数据
     * @return md5摘要
     */
    public static String md5Hex(String data) {
        return DigestUtil.md5Hex(StrUtils.bytes(data));
    }

    /**
     * 计算3MD5摘要值
     *
     * @param data 被摘要数据
     * @param salt 盐值
     * @return md5摘要
     */
    public static String md5(String data, String salt) {
        try {
            MessageDigest digest = MessageDigest.getInstance(DigestAlgorithm.MD5.getValue());
            digest.update(Base64.decode(salt));
            byte[] bytes = digest.digest(data.getBytes());
            StringBuilder sb = new StringBuilder();
            for (byte aByte : bytes) {
                sb.append(String.format("%02x", aByte));
            }
            return sb.toString();
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
        }
        return null;
    }

    /**
     * 根据应用id去创建token信息
     * 保证每一区的token一致
     *
     * @param sysId 应用ID
     * @return appToken
     * @since 1.0.2
     * @deprecated Since 1.0.4
     */
    @Deprecated
    public static String getAppToken(String sysId) {
        return getAppToken(sysId, KeyConstant.OTHER);
    }

    /**
     * 根据应用id去创建token信息
     * 保证每一区的token一致
     *
     * @param sysId 应用ID
     * @param key   密钥
     * @return appToken
     * @since 1.0.4
     */
    public static String getAppToken(String sysId, String key) {
        try {
            Algorithm algorithm = Algorithm.HMAC256(key);
            return JWT.create()
                    .withClaim("id", sysId)
                    .withClaim("sid", 0L)
                    .sign(algorithm);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }
}
